/*****************************************************************************
 *  Rohde&Schwarz DOCSIS Signal Analyzer
 *  Callbacks
 *
 *  Original Release: July 2021
 *  By: John Reid
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *****************************************************************************/

#include "rsdsa.h"
#include "rsdsa_utility.h"
#include <stdlib.h>

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
#include <sys/timeb.h>
#include <sys/types.h>
#include <unistd.h>
#define Sleep sleep
#else                       /* ANSI compatible */
#include <windows.h>
#endif


#pragma warning (disable:4100) // unreferenced formal parameter

 /*****************************************************************************
  *------------------------ Global Session Callbacks -------------------------*
  *****************************************************************************/


  /*****************************************************************************
  * Function: rsdsa_ZeroCommaString_WriteCallback
  * String => 0,'String'
   *****************************************************************************/
ViStatus rsdsa_ZeroCommaString_WriteCallback(ViSession          instrSession,
                                             ViConstString      repCapName,
                                             RsCoreAttributePtr attr,
                                             void*              value)
{
    ViChar param[RS_MAX_MESSAGE_LEN] = "";

    snprintf(param, RS_MAX_MESSAGE_LEN, "0,'%s'", (char*)value);
    return RsCore_WriteCallback(instrSession, repCapName, attr, param);
}

/*****************************************************************************
 * Function: rsdsa_logging_ReadCallback
 * Purpose:  Simulates getting logging state
 *****************************************************************************/
ViStatus rsdsa_logging_ReadCallback(ViSession          instrSession,
                                    ViConstString      repCapName,
                                    RsCoreAttributePtr attr)
{
    return VI_SUCCESS;
}

/*****************************************************************************
 * Function: rsdsa_logging_WriteCallback
 * Purpose:  Simulates setting logging state
 *****************************************************************************/
ViStatus rsdsa_logging_WriteCallback(ViSession          instrSession,
                                     ViConstString      repCapName,
                                     RsCoreAttributePtr attr,
                                     void*              value)
{
    return VI_SUCCESS;
}
